\name{array2channel}
\alias{array2channel}
\title{Convert Two-Color Targets File to One-Row-Per-Channel}
\description{
Convert a two-color targets from with one row per array to one with one row per channel.
}
\usage{
array2channel(targets, channel.codes=c(1,2), channel.columns=list(Target=c("Cy3","Cy5")), grep=FALSE)
}
\arguments{
  \item{targets}{data.frame with one row per array giving information about target samples associated covariates.}
  \item{channel.codes}{numeric or character vector of length 2 giving codes for the channels}
  \item{channel.columns}{named list of character vectors of length 2.
  Each entry gives a pair of names of columns in \code{targets} which contain channel-specific information.
  This pair of columns should be assembled into one column in the output.}
  \item{grep}{logical, if \code{TRUE} then the column names are founding by \code{grep}ing, i.e., the actual column names need only contain the names given by \code{channel.columns} as substrings}
}
\details{
This function is used to convert the usual two-color representation of target information into a form suitable for single-channel analysis.
}
\value{
data.frame with twice as many rows as \code{targets}.
Any pair of columns named by \code{channel.columns} will now be one column.
}
\seealso{
\code{\link[convert]{coerce,RGList,exprSet-method}}

An overview of methods for single channel analysis in limma is given by \link{6.SingleChannel}.
}
\examples{
targets <- data.frame(FileName=c("file1.gpr","file2.gpr"),Cy3=c("WT","KO"),Cy5=c("KO","WT"))
array2channel(targets)
}
\author{Gordon Smyth}
\keyword{htest}
